<?php

declare(strict_types=1);

namespace Drupal\simple_oauth_redirect_uri_wildcard\Plugin\Validation\Constraint;

use Drupal\simple_oauth_redirect_uri_wildcard\Validator\RedirectUriValidatorInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;

/**
 * Validates the WildcardRedirectUri constraint.
 */
class WildcardRedirectUriValidator extends ConstraintValidator implements ContainerInjectionInterface {

  /**
   * The redirect URI validator service.
   *
   * @var \Drupal\simple_oauth_redirect_uri_wildcard\Validator\RedirectUriValidatorInterface
   */
  protected RedirectUriValidatorInterface $validator;

  /**
   * Constructs a WildcardRedirectUriValidator object.
   *
   * @param \Drupal\simple_oauth_redirect_uri_wildcard\Validator\RedirectUriValidatorInterface $validator
   *   The redirect URI validator service.
   */
  public function __construct(RedirectUriValidatorInterface $validator) {
    $this->validator = $validator;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('simple_oauth_redirect_uri_wildcard.validator')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function validate($value, Constraint $constraint) {
    if (!$constraint instanceof WildcardRedirectUri) {
      throw new \InvalidArgumentException('Invalid constraint provided');
    }

    foreach ($value->getValue() as $item) {
      $uri = trim($item['value']);
      if (empty($uri)) {
        continue;
      }

      if (!$this->validator->validateSchema($uri)) {
        $this->context->addViolation($constraint->message, ['%url' => $uri]);
      }
    }
  }

}
