<?php

declare(strict_types=1);

namespace Drupal\simple_oauth_redirect_uri_wildcard\Validator;

/**
 * Interface for the redirect URI validator service.
 */
interface RedirectUriValidatorInterface {

  /**
   * Validates if a URI schema is valid and contains correct wildcard.
   *
   * @param string $uri
   *   The URI schema to validate.
   *
   * @return bool
   *   TRUE if the URI is valid and wildcard is in subdomain, FALSE otherwise.
   */
  public function validateSchema(string $uri): bool;

  /**
   * Checks if a URI matches a given schema pattern.
   *
   * @param string $uri
   *   The URI to check.
   * @param string $schema
   *   The schema pattern to match against.
   *
   * @return bool
   *   TRUE if the URI matches the schema pattern, FALSE otherwise.
   */
  public function uriMatchesSchema(string $uri, string $schema): bool;

}
